==> owncloud-8.2.9.tar.bz2: owncloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Na voljo ni dovolj prostora",
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "Could not move %s - File with this name already exists" : "Datoteke %s ni mogoče premakniti  - datoteka s tem imenom že obstaja.",
    "Could not move %s" : "Datoteke %s ni mogoče premakniti",
    "Permission denied" : "Za to opravilo ni ustreznih dovoljenj.",
    "The target folder has been moved or deleted." : "Ciljna mapa je premaknjena ali izbrisana.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Ime %s je že v mapi %s že v uporabi. Izbrati je treba drugo ime.",
    "Error when creating the file" : "Napaka med ustvarjanjem datoteke",
    "Error when creating the folder" : "Napaka med ustvarjanjem mape",
    "Unable to set upload directory." : "Mapo, v katero boste prenašali dokumente, ni mogoče določiti",
    "Invalid Token" : "Neveljaven žeton",
    "No file was uploaded. Unknown error" : "Ni poslane datoteke. Neznana napaka.",
    "There is no error, the file uploaded with success" : "Datoteka je uspešno naložena.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Poslana datoteka presega dovoljeno velikost, ki je določena z možnostjo upload_max_filesize v datoteki php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti v obrazcu HTML.",
    "The uploaded file was only partially uploaded" : "Poslan je le del datoteke.",
    "No file was uploaded" : "Ni poslane datoteke",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Failed to write to disk" : "Pisanje na disk je spodletelo",
    "Not enough storage available" : "Na voljo ni dovolj prostora",
    "Upload failed. Could not find uploaded file" : "Pošiljanje je spodletelo. Ni mogoče najti poslane datoteke.",
    "Upload failed. Could not get file info." : "Pošiljanje je spodletelo. Ni mogoče pridobiti podrobnosti datoteke.",
    "Invalid directory." : "Neveljavna mapa.",
    "Files" : "Datoteke",
    "All files" : "Vse datoteke",
    "Favorites" : "Priljubljene",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
    "Total file size {size1} exceeds upload limit {size2}" : "Skupna velikost {size1} presega omejitev velikosti {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Could not get result from server." : "Ni mogoče pridobiti podatkov s strežnika.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
    "Actions" : "Dejanja",
    "Download" : "Prejmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "Error moving file." : "Napaka premikanja datoteke.",
    "Error moving file" : "Napaka premikanja datoteke",
    "Error" : "Napaka",
    "{new_name} already exists" : "{new_name} že obstaja",
    "Could not rename file" : "Ni mogoče preimenovati datoteke",
    "Could not create file" : "Ni mogoče ustvariti datoteke",
    "Could not create folder" : "Ni mogoče ustvariti mape",
    "Error deleting file." : "Napaka brisanja datoteke.",
    "No entries in this folder match '{filter}'" : "Ni zadetkov, ki bi bili skladni z nizom '{filter}'",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "Upload" : "Pošlji",
    "Text file" : "Besedilna datoteka",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ali mapa je <strong>spremenjena</strong>.",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je <strong>izbrisana</strong>.",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je <strong>obnovljena</strong>.",
    "You created %1$s" : "Ustvarili ste %1$s",
    "%2$s created %1$s" : "%2$s je ustvaril %1$s",
    "%1$s was created in a public folder" : "Datoteka %1$s je ustvarjena v javni mapi.",
    "You changed %1$s" : "Spremenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je spremenil %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je izbrisal %1$s",
    "You restored %1$s" : "Obnovljen je predmet %1$s",
    "%2$s restored %1$s" : "Uporabnik %2$s je obnovil predmet %1$s.",
    "%s could not be renamed as it has been deleted" : "Datoteke %s ni mogoče preimenovati, ker je bila že prej izbrisana.",
    "%s could not be renamed" : "%s ni mogoče preimenovati",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanja",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "Can not be edited from here due to insufficient permissions." : "Predmeta ni mogoče urejati zaradi neustreznih dovoljenj.",
    "Settings" : "Nastavitve",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\"> za dostop do datotek peko sistema WebDAV</a>.",
    "Cancel upload" : "Prekliči pošiljanje",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračenje omejitve velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "Files are being scanned, please wait." : "Poteka preučevanje datotek, počakajte ...",
    "Currently scanning" : "Poteka preverjanje",
    "No favorites" : "Ni priljubljenih",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo izpisane tukaj."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.0.0.tar.bz2: owncloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Na voljo ni dovolj prostora",
    "Storage invalid" : "Določen prostor ni veljaven",
    "Unknown error" : "Neznana napaka",
    "Unable to set upload directory." : "Mapo, v katero boste prenašali dokumente, ni mogoče določiti",
    "Invalid Token" : "Neveljaven žeton",
    "No file was uploaded. Unknown error" : "Ni poslane datoteke. Neznana napaka.",
    "There is no error, the file uploaded with success" : "Datoteka je uspešno naložena.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Poslana datoteka presega dovoljeno velikost, ki je določena z možnostjo upload_max_filesize v datoteki php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti v obrazcu HTML.",
    "The uploaded file was only partially uploaded" : "Poslan je le del datoteke.",
    "No file was uploaded" : "Ni poslane datoteke",
    "Missing a temporary folder" : "Manjka začasna mapa",
    "Failed to write to disk" : "Pisanje na disk je spodletelo",
    "Not enough storage available" : "Na voljo ni dovolj prostora",
    "The target folder has been moved or deleted." : "Ciljna mapa je premaknjena ali izbrisana.",
    "Upload failed. Could not find uploaded file" : "Pošiljanje je spodletelo. Ni mogoče najti poslane datoteke.",
    "Upload failed. Could not get file info." : "Pošiljanje je spodletelo. Ni mogoče pridobiti podrobnosti datoteke.",
    "Invalid directory." : "Neveljavna mapa.",
    "Files" : "Datoteke",
    "All files" : "Vse datoteke",
    "Favorites" : "Priljubljene",
    "Home" : "Domači naslov",
    "Close" : "Zapri",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
    "Total file size {size1} exceeds upload limit {size2}" : "Skupna velikost {size1} presega omejitev velikosti {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
    "Error uploading file \"{fileName}\": {message}" : "Napaka pošiljanja datoteke \"{fileName}\": {message}",
    "Could not get result from server." : "Ni mogoče pridobiti podatkov s strežnika.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
    "Actions" : "Dejanja",
    "Download" : "Prejmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Details" : "Podrobnosti",
    "Select" : "Izberi",
    "Pending" : "V čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "{newName} already exists" : "{newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
    "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
    "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Ni zadetkov, ki bi bili skladni z nizom '{filter}'",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "{newname} already exists" : "{newname} že obstaja",
    "Upload" : "Pošlji",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ali mapa je <strong>spremenjena</strong>.",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je <strong>izbrisana</strong>.",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je <strong>obnovljena</strong>.",
    "You created %1$s" : "Ustvarili ste %1$s",
    "%2$s created %1$s" : "%2$s je ustvaril %1$s",
    "%1$s was created in a public folder" : "Datoteka %1$s je ustvarjena v javni mapi.",
    "You changed %1$s" : "Spremenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je spremenil %1$s",
    "You deleted %1$s" : "Izbrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je izbrisal %1$s",
    "You restored %1$s" : "Obnovljen je predmet %1$s",
    "%2$s restored %1$s" : "Uporabnik %2$s je obnovil predmet %1$s.",
    "Changed by %2$s" : "Zadnja sprememba: %2$s",
    "Deleted by %2$s" : "Izbrisano: %2$s",
    "Restored by %2$s" : "Obnovljeno: %2$s",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "File handling" : "Upravljanje z datotekami",
    "Maximum upload size" : "Največja velikost za pošiljanja",
    "max. possible: " : "največ mogoče:",
    "Save" : "Shrani",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
    "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
    "Settings" : "Nastavitve",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\"> za dostop do datotek peko sistema WebDAV</a>.",
    "Cancel upload" : "Prekliči pošiljanje",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračenje omejitve velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites" : "Ni priljubljenih",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo izpisane tukaj.",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "Nova datoteka.txt"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
